@@ -7,7 +7,6 @@ use utf8;
 
 #use Carp;
 
-use version;
 use DateTime;
 use DateTime::Locale 0.4000;
 use DateTime::TimeZone;
@@ -19,7 +18,7 @@ our @EXPORT_OK = qw( cldr_format cldr_parse );
 our @EXPORT = ();
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = version->new("1.13");
+our $VERSION = "1.14";
 
 # Default format if none is set
 our $DEFAULT_FORMAT = 'date_format_medium';
@@ -228,7 +227,7 @@ DateTime::Format::CLDR - Parse and format CLDR time patterns
     use DateTime::Format::CLDR;
     
     # 1. Basic example
-    my $cldr1 = new DateTime::Format::CLDR(
+    my $cldr1 = DateTime::Format::CLDR->new(
         pattern     => 'HH:mm:ss',
         locale      => 'de_AT',
         time_zone   => 'Europe/Vienna',
@@ -241,7 +240,7 @@ DateTime::Format::CLDR - Parse and format CLDR time patterns
     
     # 2. Get pattern from selected locale
     # pattern is taken from 'date_format_medium' in DateTime::Locale::de_AT
-    my $cldr2 = new DateTime::Format::CLDR(
+    my $cldr2 = DateTime::Format::CLDR->new(
         locale      => 'de_AT',
     );
     
@@ -249,7 +248,7 @@ DateTime::Format::CLDR - Parse and format CLDR time patterns
     # 2007-11-23T00:00:00
     
     # 3. Croak when things go wrong
-    my $cldr3 = new DateTime::Format::CLDR(
+    my $cldr3 = DateTime::Format::CLDR->new(
         locale      => 'de_AT',
         on_error    => 'croak',
     );
@@ -259,7 +258,7 @@ DateTime::Format::CLDR - Parse and format CLDR time patterns
     
     # 4. Use DateTime::Locale
     my $locale = DateTime::Locale->load('en_GB');
-    my $cldr4 = new DateTime::Format::CLDR(
+    my $cldr4 = DateTime::Format::CLDR->new(
         pattern     => $locale->datetime_format_medium,
         locale      => $locale,
     );
@@ -1297,30 +1296,6 @@ L<http://rt.cpan.org/Public/Bug/Report.html?Queue=DateTime::Format::CLDR>.
 I will be notified and then you'll automatically be notified of the progress 
 on your report as I make changes.
 
-=head1 AUTHOR
-
-    Maroš Kollár
-    CPAN ID: MAROS
-    maros [at] k-1.com
-    
-    L<http://www.revdev.at>
-
-=head1 ACKNOWLEDGEMENTS 
-
-This module was written for Revdev L<http://www.revdev.at>, a nice litte
-software company I run with Koki and Domm (L<http://search.cpan.org/~domm/>).
-
-=head1 COPYRIGHT
-
-DateTime::Format::CLDR is Copyright (c) 2008-2010 Maroš Kollár 
-- L<http://www.revdev.at>
-
-This program is free software; you can redistribute it and/or modify it under 
-the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
 =head1 SEE ALSO
 
 datetime@perl.org mailing list
@@ -1330,4 +1305,22 @@ L<http://datetime.perl.org/>
 L<DateTime>, L<DateTime::Locale>, L<DateTime::TimeZone> 
 and L<DateTime::Format::Strptime>
 
+=head1 AUTHOR
+
+    Maroš Kollár
+    CPAN ID: MAROS
+    maros [at] k-1.com
+    
+    http://www.k-1.com
+
+=head1 COPYRIGHT
+
+DateTime::Format::CLDR is Copyright (c) 2008-2012 Maroš Kollár 
+- L<http://www.k-1.com>
+
+=head1 LICENCE
+
+This library is free software, you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
